@@ -173,3 +173,65 @@ def info(filename):
         "ctime": datetime.datetime.fromtimestamp(stat.st_ctime),
         "mode": stat.st_mode,
     }
+
+
+
+size_unit_names = [
+    "B",
+    "KB",
+    "MB",
+    "GB",
+    "TB",
+    "PB",
+    "EB",
+    "ZB",
+    "YB",
+]
+
+size_unit_upper_limit = [1024 ** (index+1) for index, _ in enumerate(size_unit_names)]
+
+def get_size_deviation(unit_name):
+    unit_name = unit_name.upper()
+    x = size_unit_names.index(unit_name)
+    return 1 - (1000 ** x) / (1024 ** x)
+
+def get_unit_size(unit_name, kb_size=1024):
+    """base is the size of KB, choices are 1000 or 1024.
+    """
+    unit_name = unit_name.upper()
+    if not unit_name.endswith("B"):
+        unit_name += "B"
+    return kb_size ** size_unit_names.index(unit_name)
+
+def get_size_display(size_in_bytes):
+    """10 => 10B, 1024 => 1KB, 5.6*1024 => 5.6KB
+    """
+    final_index = 0
+    final_upper_limit = 1
+    for index, upper_limit in enumerate(size_unit_upper_limit[:-1]):
+        if upper_limit > size_in_bytes:
+            break
+        final_index = index + 1
+        final_upper_limit = upper_limit
+    return "{0:.2f}".format(size_in_bytes/final_upper_limit).rstrip("0").rstrip(".") + size_unit_names[final_index]
+
+class TemporaryFile(object):
+
+    def __init__(self, content=None, encoding="utf-8", workspace=None, workspace_prefix="", touch_file=True):
+        self.workspace = workspace or get_temp_workspace(prefix=workspace_prefix)
+        mkdir(self.workspace)
+        self.filename = str(uuid4())
+        self.filepath = os.path.join(self.workspace, self.filename)
+        if content:
+            write(self.filepath, content, encoding)
+        elif touch_file:
+            touch(self.filepath)
+    
+    def __enter__(self):
+        return self
+    
+    def __exit__(self, type, value, traceback):
+        if os.path.exists(self.filepath):
+            os.unlink(self.filepath)
+        if os.path.exists(self.workspace):
+            os.rmdir(self.workspace)
