@@ -32,6 +32,7 @@ def get_float_part(value, precision=7):
     value = int(value)
     return value
 
+
 def float_split(value, precision=7):
     if value >= 0:
         sign = 1
@@ -41,3 +42,24 @@ def float_split(value, precision=7):
     int_value = int(value)
     float_value = get_float_part(value, precision)
     return sign, int_value, float_value
+
+
+if hasattr(int, "from_bytes"):
+    from_bytes = int.from_bytes
+else:
+    def from_bytes(value_bytes, byteorder="big"):
+        t = 0
+        if byteorder.lower() != "big":
+            value_bytes = bytearray(value_bytes)
+            value_bytes.reverse()
+        else:
+            value_bytes = bytearray(value_bytes)
+        for x in value_bytes:
+            t = t*256 + x
+        return t
+
+
+try:
+    NUMERIC_TYPES = (int, long, float)
+except NameError:
+    NUMERIC_TYPES = (int, float)
