@@ -547,7 +547,7 @@ def unquote(value, quotes=None):
     return value
 
 
-def is_uuid(value):
+def is_uuid(value, allow_bad_characters=False):
     if isinstance(value, uuid.UUID):
         return True
     if isinstance(value, bytes):
@@ -573,6 +573,10 @@ def is_uuid(value):
             value2 = uuid.UUID(value)
             return True
         except ValueError:
+            if allow_bad_characters:
+                pattern = '^[a-zA-Z0-9]{8}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{4}-[a-zA-Z0-9]{12}$'
+                if re.match(pattern, value):
+                    return True
             return False
 
 def stringlist_append(string_value, new_element, separator=",", allow_duplicate=True):
